@@ -3,6 +3,7 @@
 import errno
 import os
 import platform
+import subprocess
 import sys
 import traceback
 
@@ -189,6 +190,12 @@ def build_java_execution(options, daemon):
     if options.log_levels_set and not exists(options.log_levels):
         raise Exception('Log levels file is missing: %s' % options.log_levels)
 
+    with open(os.devnull, 'w') as devnull:
+        try:
+            subprocess.check_call(['java', '-version'], stdout=devnull, stderr=devnull)
+        except (OSError, subprocess.CalledProcessError):
+            raise Exception('Java is not installed')
+
     properties = options.properties.copy()
 
     if exists(options.log_levels):
